fisx: Member List

fisx

fisx::Material Member List

This is the complete list of members for fisx::Material, including all inherited members.

getComment() const (defined in fisx::Material) | fisx::Material |
getComposition() const | fisx::Material |
getDefaultDensity() (defined in fisx::Material) | fisx::Material | inline
getDefaultThickness() (defined in fisx::Material) | fisx::Material | inline
getName() const (defined in fisx::Material) | fisx::Material |
initialize(const std::string &materialName, const double &density=1.0, const double &thickness=1.0, const std::string &comment="") (defined in fisx::Material) | fisx::Material |
Material() | fisx::Material |
Material(const std::string &materialName, const double &density=1.0, const double &thickness=1.0, const std::string &comment="") | fisx::Material |
setComposition(const std::map< std::string, double > &) | fisx::Material |
setComposition(const std::vector< std::string > &, const std::vector< double > &) | fisx::Material |
setName(const std::string &name) (defined in fisx::Material) | fisx::Material |